==> polycule-v0.0.6.tar.gz: polycule-v0.0.6/lib/src/pages/room/components/event/components/reply_user_prefix.dart <==
import 'package:flutter/material.dart';

import 'package:matrix/matrix.dart';

import '../../../../../../l10n/generated/app_localizations.dart';
import '../../../../../widgets/human_date.dart';
import '../../../../../widgets/matrix/avatar_builder/mxc_avatar.dart';

class ReplyUserPrefix extends StatelessWidget {
  const ReplyUserPrefix({super.key, required this.replyEvent});

  final Event replyEvent;

  @override
  Widget build(BuildContext context) {
    return FutureBuilder(
      future: replyEvent.fetchSenderUser(),
      builder: (context, snapshot) {
        final user = snapshot.data ?? replyEvent.senderFromMemoryOrFallback;
        final name = user.displayName ?? user.id;
        return Text.rich(
          textAlign: TextAlign.left,
          overflow: TextOverflow.ellipsis,
          TextSpan(
            children: [
              WidgetSpan(
                alignment: PlaceholderAlignment.middle,
                child: MxcAvatar(
                  uri: user.avatarUrl,
                  client: replyEvent.room.client,
                  monogram: name,
                  dimension: 24,
                ),
              ),
              TextSpan(
                text: r' ' +
                    AppLocalizations.of(context).replyUserSentDate(
                      name,
                      replyEvent.originServerTs.humanShortDate(
                        context: context,
                        fullLength: true,
                      ),
                    ),
              ),
            ],
          ),
        );
      },
    );
  }
}

==> polycule-v0.2.3.tar.gz: polycule-v0.2.3/lib/src/pages/room/components/event/components/reply_user_prefix.dart <==
import 'package:flutter/material.dart';

import '../../../../../../l10n/generated/app_localizations.dart';
import '../../../../../widgets/human_date.dart';
import '../../../../../widgets/matrix/avatar_builder/mxc_avatar.dart';
import '../../../../../widgets/matrix/scopes/event_scope.dart';

class ReplyUserPrefix extends StatelessWidget {
  const ReplyUserPrefix({super.key});

  @override
  Widget build(BuildContext context) {
    final event = EventScope.of(context).event;
    return FutureBuilder(
      future: event.fetchSenderUser(),
      builder: (context, snapshot) {
        final user = snapshot.data ?? event.senderFromMemoryOrFallback;
        final name = user.displayName ?? user.id;
        return Text.rich(
          textAlign: TextAlign.left,
          overflow: TextOverflow.ellipsis,
          TextSpan(
            children: [
              WidgetSpan(
                alignment: PlaceholderAlignment.middle,
                child: MxcAvatar(
                  uri: user.avatarUrl,
                  monogram: name,
                  dimension: 24,
                ),
              ),
              TextSpan(
                text: r' ' +
                    AppLocalizations.of(context).replyUserSentDate(
                      name,
                      event.originServerTs.humanShortDate(
                        context: context,
                        fullLength: true,
                      ),
                    ),
              ),
            ],
          ),
        );
      },
    );
  }
}
